@@ -372,7 +372,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
             if v.select_rows: result['select_rows'] = v.select_rows
             if v.submit_form_data: result['submit_form_data'] = True
             if v.button_text: result['button_text'] = v.button_text
-            if v.help_text: result['help_text'] = v.help_text
+            # if v.help_text: result['help_text'] = v.help_text
 
             icon = self.get_action_icon(v)
             if icon: result['icon'] = icon
@@ -419,9 +419,10 @@ class Renderer(JsRenderer, JsCacheRenderer):
         st = ar.get_status(**kw)
         return self.action_call(ar, ar.bound_action, st)
 
-    # def instance_handler(self, ar, obj, ba):
-    #     # Used for navigation, currently working, due to action_call override
-    #     return super(Renderer, self).instance_handler(ar, obj, ba)
+    def instance_handler(self, ar, obj, ba, **status):
+        if ar and hasattr(ar, 'get_status'):
+            status.update(ar.get_status())
+        return super(Renderer, self).instance_handler(ar, obj, ba, **status)
 
     def action_call(self, request, bound_action, status):
 
@@ -432,7 +433,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
         if request and request.subst_user:
             status[
                 constants.URL_PARAM_SUBST_USER] = request.subst_user
-        if isinstance(a, ShowEmptyTable):
+        if isinstance(a, ShowEmptyTable) and an != 'grid':
             status.update(record_id=-99998)
 
         rp = None if request is None else request.requesting_panel
@@ -484,6 +485,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
     def actions2json(self, actions_list):  # 20210517
         # v is a dict of an -> BoundCction instances
         result = []
+        hotkeys = []
 
         for ba in actions_list:
             lh = ba.get_layout_handel()
@@ -495,35 +497,61 @@ class Renderer(JsRenderer, JsCacheRenderer):
                 if lh:
                     action_descriptor.update(window_layout=lh.layout._formpanel_name)
                 if ba.action.window_type:
-                    tba = []
+                    tbas = []
                     combo_group = None
 
                     for a in ba.actor.get_toolbar_actions(
                         ba.action, get_user_profile()):
                         if a.action.combo_group == combo_group\
                             and combo_group is not None:
-                            previous = tba.pop()
+                            previous = tbas.pop()
                             if not isinstance(previous, list):
                                 previous = [previous]
-                            previous.append(a.action.action_name)
-                            tba.append(previous)
+                            tba = dict(an=a.action.action_name)
+                            help_text = a.action.help_text
+                            if help_text: tba['help_text'] = help_text
+                            previous.append(tba)
+                            tbas.append(previous)
                         else:  # is normal
-                            tba.append(a.action.action_name)
+                            tba = dict(an=a.action.action_name)
+                            help_text = a.action.help_text
+                            if help_text: tba['help_text'] = help_text
+                            tbas.append(tba)
                             combo_group = a.action.combo_group
-                    action_descriptor["toolbarActions"] = tba
+
+                        if a.action.hotkey:
+                            hotkey = vars(a.action.hotkey)
+                            if not hasattr(hotkey, 'ba'):
+                                hotkey['ba'] = a.action.action_name
+                            if hotkey not in hotkeys:
+                                hotkeys.append(hotkey)
+
+                    action_descriptor["toolbarActions"] = tbas
+
                 result.append(action_descriptor)
 
-        return result
+            if ba.action.hotkey:
+                hotkey = vars(ba.action.hotkey)
+                if not hasattr(hotkey, 'ba'):
+                    hotkey['ba'] = ba.action.action_name
+                if hotkey not in hotkeys:
+                    hotkeys.append(hotkey)
+
+        return result, hotkeys
 
     def actor2json(self, v):
         assert isclass(v) and issubclass(v, Actor)
+        al , hk = self.actions2json(v._actions_list)
         result = dict(id=v.actor_id,
-                      actions_list=self.actions2json(v._actions_list),
+                      actions_list=al,
                       label=v.get_actor_label(),
                       slave=bool(v.master),
                       editable=not v.hide_editing(get_user_profile())
                       # [py2js(b) for b in v.actions.items()]
                       )
+        if len(hk):
+            result.update(hotkeys=hk)
+
         ah = v.get_handle()
         if ah.store is None:
             settings.SITE.logger.warning("%s has no store", v)
@@ -572,16 +600,13 @@ class Renderer(JsRenderer, JsCacheRenderer):
             if wl is not None:
                 result.update(window_layout=wl._formpanel_name)
 
-        hotkeys = v.get_actions_hotkeys()
-        if hotkeys:
-            result.update(hotkeys=hotkeys)
-
         card_layout = getattr(v, "card_layout", None)
         if card_layout is not None:
             result.update(card_layout=card_layout._formpanel_name)
 
         item_layout = getattr(v, "item_layout", None)
         if item_layout is not None:
+            # print("20210629", v, "item_layout is", item_layout)
             result.update(item_layout=item_layout._formpanel_name)
         # mt + slave-tables
 
