@@ -141,26 +141,31 @@ class ApiList(View):
                 datarec = elem2rec_empty(ar, ar.ah, elem)
                 return json_response(datarec)
 
-            window_type = request.GET.get(constants.URL_PARAM_WINDOW_TYPE, "t")
+            display_mode = request.GET.get(
+                constants.URL_PARAM_DISPLAY_MODE, constants.DISPLAY_MODE_TABLE)
 
             def serialize(ar, row):
-                """Use window_type to determine which serilisation store metod and fields to use"""
-                if window_type == "t":
+                """Use display_mode to determine which serilisation store method and fields to use"""
+                if display_mode == constants.DISPLAY_MODE_TABLE:
                     return rh.store.row2list(ar, row)
-                elif window_type == "g":
+                elif display_mode == constants.DISPLAY_MODE_GALLERY:
                     # return rh.store.file2url(ar, row)
                     return row.get_gallery_item(ar)
                 else:
-                    return rh.store.row2dict(ar, row,
-                                             fields=rh.store.card_fields if window_type == "c" else rh.store.detail_fields,
-                                             card_title=ar.get_card_title(row)
-                                             )
+                    if display_mode == constants.DISPLAY_MODE_CARDS:
+                        fields = rh.store.card_fields
+                    elif display_mode == constants.DISPLAY_MODE_LIST:
+                        fields = rh.store.item_fields
+                    else:
+                        fields = rh.store.detail_fields
+                    return rh.store.row2dict(ar,
+                        row, fields=fields, card_title=ar.get_card_title(row))
 
             rows = [serialize(ar, row)
                     for row in ar.sliced_data_iterator]
 
             total_count = ar.get_total_count()
-            if window_type == "t":
+            if display_mode == constants.DISPLAY_MODE_TABLE:
                 for row in ar.create_phantom_rows():
                     if ar.limit is None or len(rows) + 1 < ar.limit or ar.limit == total_count + 1:
                         d = serialize(ar, row)
@@ -172,7 +177,7 @@ class ApiList(View):
                       success=True,
                       no_data_text=ar.no_data_text,
                       title=ar.get_title())
-            if window_type != "t":
+            if display_mode != constants.DISPLAY_MODE_TABLE:
                 mc = ar.get_main_card()
                 if mc is not None:
                     rows.insert(0, mc)
