@@ -3,7 +3,7 @@ ns = setup_from_tasks(
     globals(), "lino_react",
     languages="en de fr et".split(),
     # tolerate_sphinx_warnings=True,
-    blogref_url = 'http://luc.lino-framework.org',
+    blogref_url = 'https://luc.lino-framework.org',
     revision_control_system='git',
     # locale_dir='lino_extjs/extjs/locale',
     cleanable_files=['docs/api/lino_react.*'])
